

## Bodo Winter, Analysis of Korean Politeness Perception data, Experiment 2
## by Lucien Brown, Kaori Idemaru, Bodo Winter and Sven Grawunder
## Created: June 30, 2013
## Edited: June 30, 2013
## Additional tests after submission: October 29, 2013
## Completely renewed after reviewer feedback: January 13, 2014



################----------------------------------------------------------------------------------------------------
################ Analysis of Experiment 2: Preparation
################----------------------------------------------------------------------------------------------------

## Load in my common functions, set up working directory and load in data:

source("/Users/teeniematlock/Desktop/statistics/scripts/bodos_functions.R")
setwd("/Users/teeniematlock/Desktop/research/politeness/politeness_perception_study/all_data/")
xdata = read.csv("all_E2.csv",comment.char="")



## The English subjects 8 and 21 were non-native speakers; we exclude them:

xdata = xdata[xdata$Subject != "english/8",]
xdata = xdata[xdata$Subject != "english/21",]



## Check amount of data loss due to cut-off criterion:

xtabs(~xdata$Subject)			# 160 per person
(length(levels(xdata$Subject))*160)-nrow(xdata)		# 413 data points lost
1-nrow(xdata)/(length(levels(xdata$Subject))*160)		# 7.6%



## Log-transform reaction times:

xdata$logRT = log(xdata$RT + 1)



## Create Korean and English subsets to quickly check summary stats:

kor = xdata[xdata$Language=="korean",]
eng = xdata[xdata$Language=="english",]



## Find No. of males and females for total, for Korean and English... do the same for age:

table(kor[match(unique(kor$Subject),kor$Subject),]$Sex)	# Korean: 7 female, 3 male
table(eng[match(unique(eng$Subject),eng$Subject),]$Sex)	# English: 12 female, 10 male
mean(kor[match(unique(kor$Subject),kor$Subject),]$Age)		# mean Korean age: 22.9
mean(eng[match(unique(eng$Subject),eng$Subject),]$Age)		# mean English age: 19.40909
sd(kor[match(unique(kor$Subject),kor$Subject),]$Age)		# SD Korean age: 1.72844
sd(eng[match(unique(eng$Subject),eng$Subject),]$Age)		# SD English age: 1.140555
range(kor[match(unique(kor$Subject),kor$Subject),]$Age)	# range of Korean age: 20-26
range(eng[match(unique(eng$Subject),eng$Subject),]$Age)	# range of English age: 18-22



## Center continuous predictor variables (important because we're specifically looking at the intercept):

xdata$logRTc = xdata$logRT-mean(xdata$logRT)
xdata$trial_c = xdata$Trial-mean(xdata$Trial)
xdata$Repetition_c = xdata$Repetition-mean(xdata$Repetition)
xdata$OverallTrial_c = xdata$OverallTrial-mean(xdata$OverallTrial)

kor$logRTc = kor$logRT-mean(kor$logRT)
kor$trial_c = kor$Trial-mean(kor$Trial)
kor$Repetition_c = kor$Repetition-mean(kor$Repetition)
kor$OverallTrial_c = kor$OverallTrial-mean(kor$OverallTrial)

eng$logRTc = eng$logRT-mean(eng$logRT)
eng$trial_c = eng$Trial-mean(eng$Trial)
eng$Repetition_c = eng$Repetition-mean(eng$Repetition)
eng$OverallTrial_c = eng$OverallTrial-mean(eng$OverallTrial)




################----------------------------------------------------------------------------------------------------
## Experiment 2: Signal Detection Theory
################----------------------------------------------------------------------------------------------------
## Signal Detection Theory is not the major thrust of the analysis, since the mixed model analysis below is superior
## We use SDT mainly for comparability with other studies and as additional sanity check


## Define helper function to compute d prime:

get.dprime2 = function(temp){
	hitrate = sum((temp$HitMiss == "hit"))
	falsealarms = sum((temp$HitMiss == "falsealarm"))
	hitrate = hitrate / (hitrate + sum(temp$HitMiss == "miss"))
	falsealarms = falsealarms / (falsealarms+sum(temp$HitMiss == "creject"))
	hitrate = qnorm(hitrate,lower.tail=F)
	falsealarms = qnorm(falsealarms,lower.tail=F)
	dprime = falsealarms - hitrate	
	return(dprime)
	}



## Load plyr package for ddply function:

library(plyr)



# Compute dprime by subject, items and speaker voice:

dprime_sub = ddply(xdata, .(Subject), function(df){data.frame(language=unique(df$Language),
	dprime=get.dprime2(df))})
dprime_item = ddply(xdata, .(Scenario), function(df){data.frame(language=unique(df$Scenario),
	dprime=get.dprime2(df))})
dprime_voices = ddply(xdata, .(Voice), function(df){data.frame(language=unique(df$Voice),
	dprime=get.dprime2(df))})



# Inferential stats on d prime:

t.test(dprime ~ language,dprime_sub, var.equal=T)
# difference by language, t(30)=4.2066, p<0.0002158
t.test(dprime_sub[dprime_sub$language=="korean",]$dprime, mu=0, var.equal=T)	
# one-sample t-test against 0 for Korean speakers, t(9)=9.9575, p<0.0001
t.test(dprime_sub[dprime_sub$language=="english",]$dprime, mu=0, var.equal=T)
# one-sample t-test against 0 for English speakers, t(21)=4.6325, p<0.0001
t.test(dprime_sub$dprime,mu=0,var.equal=TRUE)
# one-sample t-test not differentiating by language, t(31)=7.0632, p<0.0001
t.test(dprime_item$dprime,mu=0,var.equal=TRUE)
# one-sample t-test by items, t(9)=8.8039, p<0.0001
t.test(dprime_voices$dprime,mu=0,var.equal=TRUE)
# one sample t-test by voices, t(7)=7.9182, p<0.0001





################----------------------------------------------------------------------------------------------------
## Experiment 2: Multilevel analysis / mixed models
################----------------------------------------------------------------------------------------------------
## This is the main part of the inferential stats
## We separate the analyses into three phases
## Phase I: Main analysis, testing only for accuracy effect
## Phase II: Secondary analysis (amending the model with control variables)
## Phase III: Additional analyses requested by reviewers


## Load lme4:
## (this analysis was done with lme4 version 0.999999-2)

library(lme4)




##########----------- Phase 1 (Main Analysis)
## Intercept only models first to look at overall accuracies:
## (this analysis is delibaretely neglecting all other information)
## (were testing for the intercept here)

## NOT USED IN ACTUAL PAPER:
# xmdl_kor_only = lmer(ACC ~ 1 + Repetition_c + 
	# (1|Subject) + (1|Scenario) + (1|Voice),kor,family="binomial",REML=F)
# summary(xmdl_kor_only)				# log odds: 0.89005, SE=0.19530, p<0.0001
# # effect of repetition: log odds: -0.04484, SE = 0.11608, p=0.699
# logit.inv(fixef(xmdl_kor_only)[1])	# predicted accuracy: 70.88995%

## NOT USED IN ACTUAL PAPER:
# xmdl_eng_only = lmer(ACC ~ 1 + Repetition_c + 
	# (1|Subject) + (1|Scenario) + (1|Voice),eng,family="binomial",REML=F)
# summary(xmdl_eng_only)				# log odds: 0.32635, SE=0.07716, p<0.0001
# # effect of repetition: log odds: -0.05825, SE = 0.06930, p=0.401
# logit.inv(fixef(xmdl_eng_only)[1])	# predicted accuracy: 58.08717%

xmdl_lang_only = lmer(ACC ~ 1 + Repetition_c + Language + 
	(1|Subject)+(1|Scenario)+(1|Voice),xdata,family="binomial",REML=F)
summary(xmdl_lang_only)
logit.inv(fixef(xmdl_lang_only)[1])	# predicted accuracy for English: 58.13174%
logit.inv(fixef(xmdl_lang_only)[1]+fixef(xmdl_lang_only)[3])	# predicted accuracy for Korean: 70.00722%
exp(fixef(xmdl_lang_only))			# odds ratios, Koreans are 1.6811157 times more likely to be correct




##########----------- Phase 2 (Secondary Analysis)
## Look at the influence of "control variables":

xmdl.interact = lmer(ACC ~ (trial_c+logRTc+OverallTrial_c)*Language+Repetition_c+	# fixed effects
	(1|Subject)+(1|Scenario)+(1|Voice)+												# random intercepts
	(0+OverallTrial_c+trial_c+logRTc|Subject),										# random slopes
	xdata,family="binomial",REML=F)
xmdl.main = lmer(ACC ~ (trial_c+logRTc+OverallTrial_c)+Language+Repetition_c+		# fixed effects
	(1|Subject)+(1|Scenario)+(1|Voice)+												# random intercepts
	(0+OverallTrial_c+trial_c+logRTc|Subject),										# random slopes
	xdata,family="binomial",REML=F)
xmdl.no = lmer(ACC ~ Language+Repetition_c+											# fixed effects
	(1|Subject)+(1|Scenario)+(1|Voice)+												# random intercepts
	(0+OverallTrial_c+trial_c+logRTc|Subject),										# random slopes
	xdata,family="binomial",REML=F)
anova(xmdl.interact,xmdl.main,test="Chisq")			# significant: keep model with interaction
anova(xmdl.main,xmdl.no,test="Chisq")				# significant
summary(xmdl.interact)								# main model to look at



## For discussion, calculate representative values of slow and fast reaction times:
## Find plausible range for log values to report:

mean(xdata$RT)
exp(mean(xdata$logRT)-0.5);exp(mean(xdata$logRT)+0.5)

# English listeners:
logit.inv(fixef(xmdl.interact)[1]+
	-0.5*(fixef(xmdl.interact)[3]))
logit.inv(fixef(xmdl.interact)[1]+
	+0.5*(fixef(xmdl.interact)[3]))

# Korean listeners:
logit.inv(fixef(xmdl.interact)[1]+fixef(xmdl.interact)[5]+
	-0.5*(fixef(xmdl.interact)[3]+fixef(xmdl.interact)[8]))
logit.inv(fixef(xmdl.interact)[1]+fixef(xmdl.interact)[5]+
	+0.5*(fixef(xmdl.interact)[3]+fixef(xmdl.interact)[8]))

# Descriptive values for comparison:
aggregate(logRT ~ ACC*Language,xdata,mean)
aggregate(RT ~ ACC*Language,xdata,mean)



##########----------- Phase 3 (Reviewer-requested additional analyses)
## A reviewer asked us to check gender effects; hence, we amend the previous model:

xmdl.gender = lmer(ACC ~ Repetition_c+Language+				# fixed effects
	Sex*speaker_gender + 
	(1|Subject)+(1|Scenario)+(1|Voice),						# random intercepts
	xdata,family="binomial",REML=F)
anova(xmdl_lang_only,xmdl.gender,test="Chisq")				# x2(3)=7.6491, p=0.05385
summary(xmdl.gender)										# no interaction, but perhaps men are better



## One reviewer wants us to see whether items5-10 are any different:
## Create a new variable that has A = items1-4 and B = items5-10:

relevant_scenarios = 5:10
xdata$scenarioAB = rep("A",nrow(xdata))
xdata[xdata$Scenario %in% relevant_scenarios,]$scenarioAB = "B"

## Test this variable in a simple analysis:

xmdl.item510.kor = lmer(ACC ~ scenarioAB + Repetition_c + 
	(1|Subject)+(1|Scenario)+(1|Voice),xdata[xdata$Language=="korean",],family="binomial",REML=F)
summary(xmdl.item510.kor)		# AB did not play a role for Koreans

xmdl.item510.eng = lmer(ACC ~ scenarioAB + Repetition_c +  
	(1|Subject)+(1|Scenario)+(1|Voice),xdata[xdata$Language=="english",],family="binomial",REML=F)
summary(xmdl.item510.eng)		# AB did play a role for English, log odds: -0.17287, SE=0.07083, p=0.0147

xmdl.item510 = lmer(ACC ~ scenarioAB*Language + Repetition_c + 
	(1|Subject)+(1|Scenario)+(1|Voice),xdata,family="binomial",REML=F)
summary(xmdl.item510)			# no language interaction, no significant main effect of scenarioAB



## Another reviewer asked us to make a significance test on the random effects:

xmdl.kor_nosub = lmer(ACC ~ 1 + Repetition_c + 
	(1|Voice)+(1|Scenario),kor,family="binomial",REML=F)
xmdl.kor_nospeak = lmer(ACC ~ 1 +  Repetition_c + 
	(1|Subject)+(1|Scenario),kor,family="binomial",REML=F)
xmdl.kor_noscen = lmer(ACC ~ 1 +  Repetition_c + 
	(1|Subject)+(1|Voice),kor,family="binomial",REML=F)

xmdl.eng_nosub = lmer(ACC ~ 1 +  Repetition_c + 
	(1|Voice)+(1|Scenario),eng,family="binomial",REML=F)
xmdl.eng_nospeak = lmer(ACC ~ 1 +  Repetition_c + 
	(1|Subject)+(1|Scenario),eng,family="binomial",REML=F)		# does not converge properly
xmdl.eng_noscen = lmer(ACC ~ 1 +  Repetition_c + 
	(1|Subject)+(1|Voice),eng,family="binomial",REML=F)

anova(xmdl.kor_nosub,xmdl_kor_only)		# x2(1) = 5.2642, p=0.02177
anova(xmdl.kor_nospeak,xmdl_kor_only)	# x2(1) = 27.887, p<0.0001
anova(xmdl.kor_noscen,xmdl_kor_only)	# x2(1) = 19.206, p<0.0001

anova(xmdl.eng_nosub,xmdl_eng_only)		# x2(1) = 35.302, p<0.0001
anova(xmdl.eng_nospeak,xmdl_eng_only)	# x2(1) = 0.3717, p=0.5421
anova(xmdl.eng_noscen,xmdl_eng_only)	# x2(1) = 1.1063, p=0.2929



## One reviewer asked us to look at random intercepts / slopes qualitatively, as Hay & Drager (2012) do:

coef(xmdl_kor_only)
coef(xmdl_eng_only)
coef(xmdl_lang_only)		# speaker S6, S7 and S8 were (overall) misinterpreted more likely than not



## For Lucien, take subjects, scenarios and speakers for Korean subset and rank them:

subs_coefs = coef(xmdl_kor_only)$Subject[,1]
names(subs_coefs) = paste("S",1:10,sep="")
subs_coefs = round(logit.inv(subs_coefs),2)
subs_coefs[order(subs_coefs)]
logit.inv(coef(xmdl_kor_only)$Scenario)		# nothing striking
speak_coefs = coef(xmdl_kor_only)$Voice[,1]
names(speak_coefs) = paste("S",1:8,sep="")
speak_coefs = round(logit.inv(speak_coefs),2)
speak_coefs[order(speak_coefs)]



## One reviewer asked us to check whether length of stay in the U.S. had an effect:

kor$longstay = rep("short",nrow(kor))
subjects_with_long_stay = c(6,9,10)
kor[(kor$SubID-30) %in% subjects_with_long_stay,]$longstay = "long"

xmdl_kor_stay = lmer(ACC ~ longstay + Repetition_c + 
	(1|Subject)+(1|Voice)+(1|Scenario),kor,family="binomial",REML=F)
summary(xmdl_kor_stay)				# log odds: 0.05921, SE=0.1948, p=0.761180
aggregate(ACC ~ longstay,kor,mean)



## One reviewer asked us to check whether dialect played a role:

kor$dialect = rep("seoul",nrow(kor))
dialectal_subjects = c(1,3,4,5,7,9)
kor[(kor$SubID-30) %in% dialectal_subjects,]$dialect = "other"

xmdl_kor_dialect = lmer(ACC ~ dialect +  Repetition_c + 
	(1|Subject)+(1|Voice)+(1|Scenario),kor,family="binomial",REML=F)
summary(xmdl_kor_dialect)				# log odds: 0.18027, SE=0.17533, p=0.304
aggregate(ACC ~ dialect,kor,mean)



## One reviewer asked us to check whether monolingualism/bilingualism of the listeners played a role:

monolinguals = c(1, 2, 6, 7, 9, 10, 11, 14, 16, 18, 23)
bilinguals = c(3, 4, 5, 12, 13, 15, 17, 19, 20, 22, 24)

xdata$bilingualism = "mono"
xdata[xdata$SubID %in% bilinguals,]$bilingualism = "bi"

xmdl_eng_biling = lmer(ACC ~ bilingualism + Repetition_c + 
	(1|Subject)+(1|Voice)+(1|Scenario),xdata[xdata$Language=="english",],family="binomial",REML=F)
summary(xmdl_eng_biling)
aggregate(ACC ~ bilingualism,xdata[xdata$Language=="english",],mean)



## One reviewer asked us to check whether there's a difference whether con was presented first or pan was presented first:

xmdl_lang_with_order = lmer(ACC ~ 1 + Repetition_c + Language + SoundFilePol + 
	(1|Subject)+(1|Scenario)+(1|Voice),xdata,family="binomial",REML=F)
summary(xmdl_lang_with_order)





################----------------------------------------------------------------------------------------------------
################ Analysis of Experiment 2: Publication-ready plots
################----------------------------------------------------------------------------------------------------



library(plyr)

## Create accuracy subsets:

sub_acc=ddply(xdata, .(Subject), function(df){data.frame(language=unique(df$Language),
	ACC=mean(df$ACC),SD=sd(df$ACC),No=length(df$ACC))})
sub_acc$SE = sub_acc$SD/sqrt(sub_acc$No)
sub_acc = sub_acc[order(sub_acc$language,sub_acc$ACC),]
sub_acc = sub_acc[order(sub_acc$language,decreasing=TRUE),]



## Plotting accuracy:

quartz("",12,5);par(mai=c(1,1.5,0.5,0.5))
emptyplot(c(1:10,12:(nrow(sub_acc)+1)),sub_acc$ACC,ylim=c(0,1))
points(c(1:10,12:(nrow(sub_acc)+1)),sub_acc$ACC,pch=19)
arrows(x0=c(1:10,12:(nrow(sub_acc)+1)),y0=sub_acc$ACC-sub_acc$SE,
	y1=sub_acc$ACC+sub_acc$SE,angle=90,code=3,length=0.05)
abline(h=0.5,lty="dashed",lwd=2)
abline(v=11,lwd=2)
axis(side=2,at=seq(0,1,0.2),labels=seq(0,1,0.2),las=2,font=2,cex.axis=1.25)
axis(side=1,at=c(1,5.5,10),
	labels=c("S1","...","S10"))
axis(side=1,at=c(12,23,nrow(sub_acc)+1),
	labels=c("S11","...","S32"))
axis(side=1,at=c(5.5,23),
	labels=c("Korean listeners","English listeners"),
	tick=F,line=2,cex.axis=1.5,font=2)
mtext(side=2,"Accuracy",cex=1.5,font=2,line=3.5)

